@@ -16,16 +16,18 @@
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301 USA.
  *
- * Copyright (C) 2016-2018 Aleksander Morgado <aleksander@aleksander.es>
+ * Copyright (C) 2016-2019 Aleksander Morgado <aleksander@aleksander.es>
  */
 
 #include <string.h>
 
 #include "qmi-compat.h"
-#include "qmi-utils.h"
+#include "qmi-utils-private.h"
+#include "qmi-enum-types.h"
 
 #ifndef QMI_DISABLE_DEPRECATED
 
+/*****************************************************************************/
 
 #if defined UTILS_ENABLE_TRACE
 static void
@@ -625,6 +627,78 @@ qmi_utils_write_fixed_size_string_to_buffer (guint8      **buffer,
     *buffer_size = (*buffer_size) - fixed_size;
 }
 
+/*****************************************************************************/
+
+gchar *
+qmi_message_get_printable (QmiMessage  *self,
+                           const gchar *line_prefix)
+{
+    return qmi_message_get_printable_full (self, NULL, line_prefix);
+}
+
+gboolean
+qmi_message_get_version_introduced (QmiMessage *self,
+                                    guint      *major,
+                                    guint      *minor)
+{
+    return qmi_message_get_version_introduced_full (self, NULL, major, minor);
+}
+
+gboolean
+qmi_message_get_version_introduced_full (QmiMessage        *self,
+                                         QmiMessageContext *context,
+                                         guint             *major,
+                                         guint             *minor)
+{
+    /* We keep the method just avoid breaking API, but this is really no longer
+     * usable */
+    return FALSE;
+}
+
+gboolean
+qmi_message_tlv_read_gfloat (QmiMessage  *self,
+                             gsize        tlv_offset,
+                             gsize       *offset,
+                             gfloat      *out,
+                             GError     **error)
+{
+    return qmi_message_tlv_read_gfloat_endian (self, tlv_offset, offset, __QMI_ENDIAN_HOST, out, error);
+}
+
+/*****************************************************************************/
+
+gboolean
+qmi_device_close (QmiDevice *self,
+                  GError **error)
+{
+    g_return_val_if_fail (QMI_IS_DEVICE (self), FALSE);
+    qmi_device_close_async (self, 0, NULL, NULL, NULL);
+    return TRUE;
+}
+
+QmiMessage *
+qmi_device_command_finish (QmiDevice     *self,
+                           GAsyncResult  *res,
+                           GError       **error)
+{
+    return qmi_device_command_full_finish (self, res, error);
+}
+
+void
+qmi_device_command (QmiDevice           *self,
+                    QmiMessage          *message,
+                    guint                timeout,
+                    GCancellable        *cancellable,
+                    GAsyncReadyCallback  callback,
+                    gpointer             user_data)
+{
+    qmi_device_command_full (self, message, NULL, timeout, cancellable, callback, user_data);
+}
+
+/*****************************************************************************/
+
+#if defined HAVE_QMI_MESSAGE_DMS_SET_SERVICE_PROGRAMMING_CODE
+
 gboolean
 qmi_message_dms_set_service_programming_code_input_get_new (
     QmiMessageDmsSetServiceProgrammingCodeInput *self,
@@ -661,30 +735,9 @@ qmi_message_dms_set_service_programming_code_input_set_current (
   return qmi_message_dms_set_service_programming_code_input_set_current_code (self, arg_current, error);
 }
 
-gchar *
-qmi_message_get_printable (QmiMessage  *self,
-                           const gchar *line_prefix)
-{
-    return qmi_message_get_printable_full (self, NULL, line_prefix);
-}
+#endif /* HAVE_QMI_MESSAGE_DMS_SET_SERVICE_PROGRAMMING_CODE */
 
-gboolean
-qmi_message_get_version_introduced (QmiMessage *self,
-                                    guint      *major,
-                                    guint      *minor)
-{
-    return qmi_message_get_version_introduced_full (self, NULL, major, minor);
-}
-
-gboolean
-qmi_message_tlv_read_gfloat (QmiMessage  *self,
-                             gsize        tlv_offset,
-                             gsize       *offset,
-                             gfloat      *out,
-                             GError     **error)
-{
-    return qmi_message_tlv_read_gfloat_endian (self, tlv_offset, offset, __QMI_ENDIAN_HOST, out, error);
-}
+/*****************************************************************************/
 
 #define SESSION_INFORMATION_DEPRECATED_METHOD(BUNDLE_SUBSTR,METHOD_SUBSTR)                                 \
     gboolean                                                                                               \
@@ -721,13 +774,31 @@ qmi_message_tlv_read_gfloat (QmiMessage  *self,
         return ret;                                                                                        \
     }
 
-SESSION_INFORMATION_DEPRECATED_METHOD (ReadTransparent,   read_transparent)
-SESSION_INFORMATION_DEPRECATED_METHOD (ReadRecord,        read_record)
+#if defined HAVE_QMI_MESSAGE_UIM_READ_TRANSPARENT
+SESSION_INFORMATION_DEPRECATED_METHOD (ReadTransparent, read_transparent)
+#endif
+#if defined HAVE_QMI_MESSAGE_UIM_READ_RECORD
+SESSION_INFORMATION_DEPRECATED_METHOD (ReadRecord, read_record)
+#endif
+#if defined HAVE_QMI_MESSAGE_UIM_GET_FILE_ATTRIBUTES
 SESSION_INFORMATION_DEPRECATED_METHOD (GetFileAttributes, get_file_attributes)
-SESSION_INFORMATION_DEPRECATED_METHOD (SetPinProtection,  set_pin_protection)
-SESSION_INFORMATION_DEPRECATED_METHOD (VerifyPin,         verify_pin)
-SESSION_INFORMATION_DEPRECATED_METHOD (UnblockPin,        unblock_pin)
-SESSION_INFORMATION_DEPRECATED_METHOD (ChangePin,         change_pin)
+#endif
+#if defined HAVE_QMI_MESSAGE_UIM_SET_PIN_PROTECTION
+SESSION_INFORMATION_DEPRECATED_METHOD (SetPinProtection, set_pin_protection)
+#endif
+#if defined HAVE_QMI_MESSAGE_UIM_VERIFY_PIN
+SESSION_INFORMATION_DEPRECATED_METHOD (VerifyPin, verify_pin)
+#endif
+#if defined HAVE_QMI_MESSAGE_UIM_UNBLOCK_PIN
+SESSION_INFORMATION_DEPRECATED_METHOD (UnblockPin, unblock_pin)
+#endif
+#if defined HAVE_QMI_MESSAGE_UIM_CHANGE_PIN
+SESSION_INFORMATION_DEPRECATED_METHOD (ChangePin, change_pin)
+#endif
+
+/*****************************************************************************/
+
+#if defined HAVE_QMI_MESSAGE_WDA_GET_DATA_FORMAT
 
 gboolean
 qmi_message_wda_get_data_format_output_get_uplink_data_aggregation_max_size (
@@ -738,15 +809,235 @@ qmi_message_wda_get_data_format_output_get_uplink_data_aggregation_max_size (
     return qmi_message_wda_get_data_format_output_get_downlink_data_aggregation_max_datagrams (self, value_uplink_data_aggregation_max_size, error);
 }
 
-gboolean
-qmi_device_close (QmiDevice *self,
-                  GError **error)
+#endif /* HAVE_QMI_MESSAGE_WDA_GET_DATA_FORMAT */
+
+/*****************************************************************************/
+
+GType
+qmi_dms_dell_firmware_version_type_get_type (void)
 {
-    g_return_val_if_fail (QMI_IS_DEVICE (self), FALSE);
-    qmi_device_close_async (self, 0, NULL, NULL, NULL);
-    return TRUE;
+    return qmi_dms_foxconn_firmware_version_type_get_type ();
 }
 
+const gchar *
+qmi_dms_dell_firmware_version_type_get_string (QmiDmsDellFirmwareVersionType val)
+{
+    return qmi_dms_foxconn_firmware_version_type_get_string ((QmiDmsFoxconnFirmwareVersionType) val);
+}
+
+#if defined HAVE_QMI_MESSAGE_DMS_FOXCONN_GET_FIRMWARE_VERSION
+
+GType
+qmi_message_dms_dell_get_firmware_version_output_get_type (void)
+{
+    return qmi_message_dms_foxconn_get_firmware_version_output_get_type ();
+}
+
+gboolean
+qmi_message_dms_dell_get_firmware_version_output_get_version (
+    QmiMessageDmsDellGetFirmwareVersionOutput *self,
+    const gchar **value_version,
+    GError **error)
+{
+    return qmi_message_dms_foxconn_get_firmware_version_output_get_version (self, value_version, error);
+}
+
+gboolean
+qmi_message_dms_dell_get_firmware_version_output_get_result (
+    QmiMessageDmsDellGetFirmwareVersionOutput *self,
+    GError **error)
+{
+    return qmi_message_dms_foxconn_get_firmware_version_output_get_result (self, error);
+}
+
+GType
+qmi_message_dms_dell_get_firmware_version_input_get_type (void)
+{
+    return qmi_message_dms_foxconn_get_firmware_version_input_get_type ();
+}
+
+gboolean
+qmi_message_dms_dell_get_firmware_version_input_get_version_type (
+    QmiMessageDmsDellGetFirmwareVersionInput *self,
+    QmiDmsDellFirmwareVersionType *value_version_type,
+    GError **error)
+{
+    return qmi_message_dms_foxconn_get_firmware_version_input_get_version_type (self, (QmiDmsFoxconnFirmwareVersionType *)value_version_type, error);
+}
+
+gboolean
+qmi_message_dms_dell_get_firmware_version_input_set_version_type (
+    QmiMessageDmsDellGetFirmwareVersionInput *self,
+    QmiDmsDellFirmwareVersionType value_version_type,
+    GError **error)
+{
+    return qmi_message_dms_foxconn_get_firmware_version_input_set_version_type (self, (QmiDmsFoxconnFirmwareVersionType)value_version_type, error);
+}
+
+QmiMessageDmsDellGetFirmwareVersionInput *
+qmi_message_dms_dell_get_firmware_version_input_ref (QmiMessageDmsDellGetFirmwareVersionInput *self)
+{
+    return qmi_message_dms_foxconn_get_firmware_version_input_ref (self);
+}
+
+void
+qmi_message_dms_dell_get_firmware_version_input_unref (QmiMessageDmsDellGetFirmwareVersionInput *self)
+{
+    qmi_message_dms_foxconn_get_firmware_version_input_unref (self);
+}
+
+QmiMessageDmsDellGetFirmwareVersionInput *
+qmi_message_dms_dell_get_firmware_version_input_new (void)
+{
+    return qmi_message_dms_foxconn_get_firmware_version_input_new ();
+}
+
+QmiMessageDmsDellGetFirmwareVersionOutput *
+qmi_message_dms_dell_get_firmware_version_output_ref (QmiMessageDmsDellGetFirmwareVersionOutput *self)
+{
+    return qmi_message_dms_foxconn_get_firmware_version_output_ref (self);
+}
+
+void
+qmi_message_dms_dell_get_firmware_version_output_unref (QmiMessageDmsDellGetFirmwareVersionOutput *self)
+{
+    qmi_message_dms_foxconn_get_firmware_version_output_unref (self);
+}
+
+void
+qmi_client_dms_dell_get_firmware_version (
+    QmiClientDms *self,
+    QmiMessageDmsDellGetFirmwareVersionInput *input,
+    guint timeout,
+    GCancellable *cancellable,
+    GAsyncReadyCallback callback,
+    gpointer user_data)
+{
+    qmi_client_dms_foxconn_get_firmware_version (self, input, timeout, cancellable, callback, user_data);
+}
+
+QmiMessageDmsDellGetFirmwareVersionOutput *
+qmi_client_dms_dell_get_firmware_version_finish (
+    QmiClientDms *self,
+    GAsyncResult *res,
+    GError **error)
+{
+    return qmi_client_dms_foxconn_get_firmware_version_finish (self, res, error);
+}
+
+#endif /* HAVE_QMI_MESSAGE_DMS_FOXCONN_GET_FIRMWARE_VERSION */
+
+/*****************************************************************************/
+
+GType
+qmi_dms_dell_device_mode_get_type (void)
+{
+    return qmi_dms_foxconn_device_mode_get_type ();
+}
+
+const gchar *
+qmi_dms_dell_device_mode_get_string (QmiDmsDellDeviceMode val)
+{
+    return qmi_dms_foxconn_device_mode_get_string ((QmiDmsFoxconnDeviceMode) val);
+}
+
+#if defined HAVE_QMI_MESSAGE_DMS_FOXCONN_CHANGE_DEVICE_MODE
+
+GType
+qmi_message_dms_dell_change_device_mode_input_get_type (void)
+{
+    return qmi_message_dms_foxconn_change_device_mode_input_get_type ();
+}
+
+gboolean
+qmi_message_dms_dell_change_device_mode_input_get_mode (
+    QmiMessageDmsDellChangeDeviceModeInput *self,
+    QmiDmsDellDeviceMode *value_mode,
+    GError **error)
+{
+    return qmi_message_dms_foxconn_change_device_mode_input_get_mode (self, (QmiDmsFoxconnDeviceMode *) value_mode, error);
+}
+
+gboolean
+qmi_message_dms_dell_change_device_mode_input_set_mode (
+    QmiMessageDmsDellChangeDeviceModeInput *self,
+    QmiDmsDellDeviceMode value_mode,
+    GError **error)
+{
+    return qmi_message_dms_foxconn_change_device_mode_input_set_mode (self, (QmiDmsFoxconnDeviceMode) value_mode, error);
+}
+
+QmiMessageDmsDellChangeDeviceModeInput *
+qmi_message_dms_dell_change_device_mode_input_ref (QmiMessageDmsDellChangeDeviceModeInput *self)
+{
+    return qmi_message_dms_foxconn_change_device_mode_input_ref (self);
+}
+
+void
+qmi_message_dms_dell_change_device_mode_input_unref (QmiMessageDmsDellChangeDeviceModeInput *self)
+{
+    qmi_message_dms_foxconn_change_device_mode_input_unref (self);
+}
+
+QmiMessageDmsDellChangeDeviceModeInput *
+qmi_message_dms_dell_change_device_mode_input_new (void)
+{
+    return qmi_message_dms_foxconn_change_device_mode_input_new ();
+}
+
+GType
+qmi_message_dms_dell_change_device_mode_output_get_type (void)
+{
+    return qmi_message_dms_foxconn_change_device_mode_output_get_type ();
+}
+
+gboolean
+qmi_message_dms_dell_change_device_mode_output_get_result (
+    QmiMessageDmsDellChangeDeviceModeOutput *self,
+    GError **error)
+{
+    return qmi_message_dms_foxconn_change_device_mode_output_get_result (self, error);
+}
+
+QmiMessageDmsDellChangeDeviceModeOutput *
+qmi_message_dms_dell_change_device_mode_output_ref (QmiMessageDmsDellChangeDeviceModeOutput *self)
+{
+    return qmi_message_dms_foxconn_change_device_mode_output_ref (self);
+}
+
+void
+qmi_message_dms_dell_change_device_mode_output_unref (QmiMessageDmsDellChangeDeviceModeOutput *self)
+{
+    qmi_message_dms_foxconn_change_device_mode_output_unref (self);
+}
+
+void
+qmi_client_dms_dell_change_device_mode (
+    QmiClientDms *self,
+    QmiMessageDmsDellChangeDeviceModeInput *input,
+    guint timeout,
+    GCancellable *cancellable,
+    GAsyncReadyCallback callback,
+    gpointer user_data)
+{
+    qmi_client_dms_foxconn_change_device_mode (self, input, timeout, cancellable, callback, user_data);
+}
+
+QmiMessageDmsDellChangeDeviceModeOutput *
+qmi_client_dms_dell_change_device_mode_finish (
+    QmiClientDms *self,
+    GAsyncResult *res,
+    GError **error)
+{
+    return qmi_client_dms_foxconn_change_device_mode_finish (self, res, error);
+}
+
+#endif /* HAVE_QMI_MESSAGE_DMS_FOXCONN_CHANGE_DEVICE_MODE */
+
+/*****************************************************************************/
+
+#if defined HAVE_QMI_MESSAGE_NAS_GET_OPERATOR_NAME
+
 gboolean
 qmi_message_nas_get_operator_name_output_get_operator_nitz_information (
     QmiMessageNasGetOperatorNameOutput *self,
@@ -779,6 +1070,10 @@ qmi_message_nas_get_operator_name_output_get_operator_nitz_information (
     return TRUE;
 }
 
+#endif /* HAVE_QMI_MESSAGE_NAS_GET_OPERATOR_NAME */
+
+#if defined HAVE_QMI_INDICATION_NAS_OPERATOR_NAME
+
 gboolean
 qmi_indication_nas_operator_name_output_get_operator_nitz_information (
     QmiIndicationNasOperatorNameOutput *self,
@@ -811,6 +1106,12 @@ qmi_indication_nas_operator_name_output_get_operator_nitz_information (
     return TRUE;
 }
 
+#endif /* HAVE_QMI_INDICATION_NAS_OPERATOR_NAME */
+
+/*****************************************************************************/
+
+#if defined HAVE_QMI_MESSAGE_NAS_GET_HOME_NETWORK
+
 gboolean
 qmi_message_nas_get_home_network_output_get_home_network_3gpp2 (
     QmiMessageNasGetHomeNetworkOutput *self,
@@ -839,4 +1140,6 @@ qmi_message_nas_get_home_network_output_get_home_network_3gpp2 (
     return TRUE;
 }
 
+#endif /* HAVE_QMI_MESSAGE_NAS_GET_HOME_NETWORK */
+
 #endif /* QMI_DISABLE_DEPRECATED */
