@@ -33,11 +33,11 @@
 #include <errno.h>
 
 #include "qmi-utils.h"
+#include "qmi-utils-private.h"
 #include "qmi-error-types.h"
 
 /**
  * SECTION:qmi-utils
- * @title: Common utilities
  *
  * This section exposes a set of common utilities that may be used to work
  * with the QMI library.
@@ -131,6 +131,14 @@ __qmi_string_utf8_validate_printable (const guint8 *utf8,
     g_assert (utf8);
     g_assert (utf8_len);
 
+    /* Ignore all trailing NUL bytes, if any */
+    while ((utf8_len > 0) && (utf8[utf8_len - 1] == '\0'))
+        utf8_len--;
+
+    /* An empty string */
+    if (!utf8_len)
+        return TRUE;
+
     /* First check if valid UTF-8 */
     init = (const gchar *)utf8;
     if (!g_utf8_validate (init, utf8_len, NULL))
@@ -389,10 +397,16 @@ gchar *
 __qmi_string_utf8_from_ucs2le (const guint8 *ucs2le,
                                gsize         ucs2le_len)
 {
-    /* UCS2 data length must be multiple of 2, otherwise it's not UCS2 */
+    gsize               ucs2he_nchars;
+    g_autofree guint16 *ucs2he = NULL;
+
+    /* UCS2 data length given in bytes must be multiple of 2 */
     if (ucs2le_len % 2 != 0)
         return NULL;
 
+    /* Convert length from bytes to number of ucs2 characters */
+    ucs2he_nchars = ucs2le_len / 2;
+
     /* We'll attempt to convert UCS2 to UTF-8, using GLib's support to convert
      * from UTF-16 to UTF-8 (given that UCS2 is a subset of UTF-16). In order
      * to do so, we need the input string in "host endian", so if we're in a
@@ -401,25 +415,22 @@ __qmi_string_utf8_from_ucs2le (const guint8 *ucs2le,
      *
      * We don't want to use g_convert() because that would mean requiring
      * full iconv() support in the system.
+     *
+     * We're using an extra allocation always because we need to increase
+     * alignment (guint8 -> (guint16)gunichar2)
      */
+    ucs2he = g_new (guint16, ucs2he_nchars);
+    g_assert (sizeof (guint16) * ucs2he_nchars == ucs2le_len);
+    memcpy (ucs2he, ucs2le, ucs2le_len);
 #if G_BYTE_ORDER == G_BIG_ENDIAN
     {
-        gchar *tmp;
-        guint8 *ucs2he = NULL;
         guint i;
 
-        ucs2he = g_malloc (ucs2le_len);
-        for (i = 0; i < ucs2le_len; i+=2) {
-            ucs2he[i]   = ucs2le[i+1];
-            ucs2he[i+1] = ucs2le[i];
-        }
-        tmp = g_utf16_to_utf8 ((const gunichar2 *)ucs2he, ucs2le_len / 2, NULL, NULL, NULL);
-        g_free (ucs2he);
-        return tmp;
+        for (i = 0; i < ucs2he_nchars; i++)
+            ucs2he[i] = GUINT16_FROM_LE (ucs2he[i]);
     }
-#else
-    return g_utf16_to_utf8 ((const gunichar2 *)ucs2le, ucs2le_len / 2, NULL, NULL, NULL);
 #endif
+    return g_utf16_to_utf8 ((const gunichar2 *)ucs2he, ucs2he_nchars, NULL, NULL, NULL);
 }
 /*****************************************************************************/
 
