@@ -29,6 +29,8 @@ test_generated_core (TestFixture *fixture)
 /*****************************************************************************/
 /* DMS Get IDs */
 
+#if defined HAVE_QMI_MESSAGE_DMS_GET_IDS
+
 static void
 dms_get_ids_ready (QmiClientDms *client,
                    GAsyncResult *res,
@@ -103,9 +105,13 @@ test_generated_dms_get_ids (TestFixture *fixture)
     test_fixture_loop_run (fixture);
 }
 
+#endif /* HAVE_QMI_MESSAGE_DMS_GET_IDS */
+
 /*****************************************************************************/
 /* DMS UIM Get PIN Status */
 
+#if defined HAVE_QMI_MESSAGE_DMS_UIM_GET_PIN_STATUS
+
 static void
 dms_uim_get_pin_status_ready (QmiClientDms *client,
                               GAsyncResult *res,
@@ -193,9 +199,13 @@ test_generated_dms_uim_get_pin_status (TestFixture *fixture)
     test_fixture_loop_run (fixture);
 }
 
+#endif /* HAVE_QMI_MESSAGE_DMS_UIM_GET_PIN_STATUS */
+
 /*****************************************************************************/
 /* DMS UIM Verify PIN */
 
+#if defined HAVE_QMI_MESSAGE_DMS_UIM_VERIFY_PIN
+
 static void
 dms_uim_verify_pin_ready (QmiClientDms *client,
                           GAsyncResult *res,
@@ -256,6 +266,8 @@ test_generated_dms_uim_verify_pin (TestFixture *fixture)
     test_fixture_loop_run (fixture);
 }
 
+#endif /* HAVE_QMI_MESSAGE_DMS_UIM_VERIFY_PIN */
+
 /*****************************************************************************/
 /* DMS Get Time
  *
@@ -265,6 +277,8 @@ test_generated_dms_uim_verify_pin (TestFixture *fixture)
  * read of the same buffer, as QMI_DMS_TIME_SOURCE_DEVICE is actually 0x0000.
  */
 
+#if defined HAVE_QMI_MESSAGE_DMS_GET_TIME
+
 static void
 dms_get_time_ready (QmiClientDms *client,
                     GAsyncResult *res,
@@ -337,9 +351,13 @@ test_generated_dms_get_time (TestFixture *fixture)
     test_fixture_loop_run (fixture);
 }
 
+#endif /* HAVE_QMI_MESSAGE_DMS_GET_TIME */
+
 /*****************************************************************************/
 /* NAS Network Scan */
 
+#if defined HAVE_QMI_MESSAGE_NAS_NETWORK_SCAN
+
 typedef struct {
     guint16 mcc;
     guint16 mnc;
@@ -587,9 +605,13 @@ test_generated_nas_network_scan (TestFixture *fixture)
     test_fixture_loop_run (fixture);
 }
 
+#endif /* HAVE_QMI_MESSAGE_NAS_NETWORK_SCAN */
+
 /*****************************************************************************/
 /* NAS Get Cell Location */
 
+#if defined HAVE_QMI_MESSAGE_NAS_GET_CELL_LOCATION_INFO
+
 static void
 nas_get_cell_location_info_ready (QmiClientNas *client,
                                   GAsyncResult *res,
@@ -647,9 +669,13 @@ test_generated_nas_get_cell_location_info (TestFixture *fixture)
     test_fixture_loop_run (fixture);
 }
 
+#endif /* HAVE_QMI_MESSAGE_NAS_GET_CELL_LOCATION_INFO */
+
 /*****************************************************************************/
 /* NAS Get Serving System */
 
+#if defined HAVE_QMI_MESSAGE_NAS_GET_SERVING_SYSTEM
+
 static void
 nas_get_serving_system_ready (QmiClientNas *client,
                               GAsyncResult *res,
@@ -679,11 +705,11 @@ nas_get_serving_system_ready (QmiClientNas *client,
         guint16 mnc;
         const gchar *description;
 
-        if (qmi_message_nas_get_serving_system_output_get_current_plmn (output, &mcc, &mnc, &description, NULL)) {
-            g_assert_cmpuint (mcc, ==, 222);
-            g_assert_cmpuint (mnc, ==, 50);
-            g_assert_cmpstr (description, ==, "Iliad");
-        }
+        g_assert (qmi_message_nas_get_serving_system_output_get_current_plmn (output, &mcc, &mnc, &description, &error));
+        g_assert_no_error (error);
+        g_assert_cmpuint (mcc, ==, 222);
+        g_assert_cmpuint (mnc, ==, 50);
+        g_assert_cmpstr (description, ==, "Iliad");
     }
 
     qmi_message_nas_get_serving_system_output_unref (output);
@@ -730,9 +756,13 @@ test_generated_nas_get_serving_system (TestFixture *fixture)
     test_fixture_loop_run (fixture);
 }
 
+#endif /* HAVE_QMI_MESSAGE_NAS_GET_SERVING_SYSTEM */
+
 /*****************************************************************************/
 /* NAS Get System Info */
 
+#if defined HAVE_QMI_MESSAGE_NAS_GET_SYSTEM_INFO
+
 static void
 nas_get_system_info_ready (QmiClientNas *client,
                            GAsyncResult *res,
@@ -885,8 +915,12 @@ test_generated_nas_get_system_info (TestFixture *fixture)
     test_fixture_loop_run (fixture);
 }
 
+#endif
+
 /*****************************************************************************/
 
+#if defined HAVE_QMI_MESSAGE_NAS_GET_CELL_LOCATION_INFO
+
 static void
 nas_get_cell_location_info_invalid_response_ready (QmiClientNas *client,
                                                    GAsyncResult *res,
@@ -937,6 +971,8 @@ test_generated_nas_get_cell_location_info_invalid_response (TestFixture *fixture
     test_fixture_loop_run (fixture);
 }
 
+#endif
+
 /*****************************************************************************/
 
 int main (int argc, char **argv)
@@ -946,19 +982,35 @@ int main (int argc, char **argv)
     /* Test the setup/teardown test methods */
     TEST_ADD ("/libqmi-glib/generated/core", test_generated_core);
 
-    /* DMS */
-    TEST_ADD ("/libqmi-glib/generated/dms/get-ids",                test_generated_dms_get_ids);
-    TEST_ADD ("/libqmi-glib/generated/dms/uim-get-pin-status",     test_generated_dms_uim_get_pin_status);
-    TEST_ADD ("/libqmi-glib/generated/dms/uim-verify-pin",         test_generated_dms_uim_verify_pin);
-    TEST_ADD ("/libqmi-glib/generated/dms/get-time",               test_generated_dms_get_time);
-    /* NAS */
-    TEST_ADD ("/libqmi-glib/generated/nas/network-scan",           test_generated_nas_network_scan);
-    TEST_ADD ("/libqmi-glib/generated/nas/get-cell-location-info", test_generated_nas_get_cell_location_info);
-    TEST_ADD ("/libqmi-glib/generated/nas/get-serving-system",     test_generated_nas_get_serving_system);
-    TEST_ADD ("/libqmi-glib/generated/nas/get-system-info",        test_generated_nas_get_system_info);
+#if defined HAVE_QMI_MESSAGE_DMS_GET_IDS
+    TEST_ADD ("/libqmi-glib/generated/dms/get-ids", test_generated_dms_get_ids);
+#endif
+#if defined HAVE_QMI_MESSAGE_DMS_UIM_GET_PIN_STATUS
+    TEST_ADD ("/libqmi-glib/generated/dms/uim-get-pin-status", test_generated_dms_uim_get_pin_status);
+#endif
+#if defined HAVE_QMI_MESSAGE_DMS_UIM_VERIFY_PIN
+    TEST_ADD ("/libqmi-glib/generated/dms/uim-verify-pin", test_generated_dms_uim_verify_pin);
+#endif
+#if defined HAVE_QMI_MESSAGE_DMS_GET_TIME
+    TEST_ADD ("/libqmi-glib/generated/dms/get-time", test_generated_dms_get_time);
+#endif
 
-    /* Invalid responses */
+#if defined HAVE_QMI_MESSAGE_NAS_NETWORK_SCAN
+    TEST_ADD ("/libqmi-glib/generated/nas/network-scan", test_generated_nas_network_scan);
+#endif
+#if defined HAVE_QMI_MESSAGE_NAS_GET_CELL_LOCATION_INFO
+    TEST_ADD ("/libqmi-glib/generated/nas/get-cell-location-info", test_generated_nas_get_cell_location_info);
+#endif
+#if defined HAVE_QMI_MESSAGE_NAS_GET_SERVING_SYSTEM
+    TEST_ADD ("/libqmi-glib/generated/nas/get-serving-system", test_generated_nas_get_serving_system);
+#endif
+#if defined HAVE_QMI_MESSAGE_NAS_GET_SYSTEM_INFO
+    TEST_ADD ("/libqmi-glib/generated/nas/get-system-info", test_generated_nas_get_system_info);
+#endif
+
+#if defined HAVE_QMI_MESSAGE_NAS_GET_CELL_LOCATION_INFO
     TEST_ADD ("/libqmi-glib/generated/nas/invalid/get-cell-location-info", test_generated_nas_get_cell_location_info_invalid_response);
+#endif
 
     return g_test_run ();
 }
