@@ -18,10 +18,7 @@
 #include <string.h>
 #include <stdio.h>
 
-#include "qmi-message.h"
-#include "qmi-errors.h"
-#include "qmi-error-types.h"
-#include "qmi-utils.h"
+#include <libqmi-glib.h>
 
 /*****************************************************************************/
 
@@ -65,14 +62,12 @@ _g_assert_cmpmem (gconstpointer mem1,
                   gconstpointer mem2,
                   gsize         size2)
 {
-    gchar *str1;
-    gchar *str2;
+    g_autofree gchar *str1 = NULL;
+    g_autofree gchar *str2 = NULL;
 
     str1 = __str_hex (mem1, size1, ':');
     str2 = __str_hex (mem2, size2, ':');
     g_assert_cmpstr (str1, ==, str2);
-    g_free (str1);
-    g_free (str2);
 }
 
 /*****************************************************************************/
@@ -82,40 +77,31 @@ test_message_parse_common (const guint8 *buffer,
                            guint buffer_len,
                            guint n_expected_messages)
 {
-    GError *error = NULL;
-    GByteArray *array;
-    guint n_messages = 0;
+    g_autoptr(GByteArray) array = NULL;
+    guint                 n_messages = 0;
 
     array = g_byte_array_sized_new (buffer_len);
     g_byte_array_append (array, buffer, buffer_len);
 
     do {
-        QmiMessage *message;
-        gchar *printable;
+        g_autoptr(GError)      error = NULL;
+        g_autoptr(QmiMessage)  message = NULL;
+        g_autofree gchar      *printable = NULL;
 
         message = qmi_message_new_from_raw (array, &error);
         if (!message) {
-            if (error) {
-                if (n_messages < n_expected_messages)
-                    g_printerr ("error creating message from raw data: '%s'\n", error->message);
-                g_error_free (error);
-            }
+            if (error && (n_messages < n_expected_messages))
+                g_printerr ("error creating message from raw data: '%s'\n", error->message);
             break;
         }
 
         printable = qmi_message_get_printable_full (message, NULL, "");
-#ifdef TEST_PRINT_MESSAGE
-        g_print ("\n%s\n", printable);
-#endif
-        g_free (printable);
+        g_debug ("%s", printable);
 
         n_messages++;
-        qmi_message_unref (message);
     } while (array->len > 0);
 
     g_assert_cmpuint (n_messages, ==, n_expected_messages);
-
-    g_byte_array_unref (array);
 }
 
 static void
@@ -177,12 +163,19 @@ test_message_parse_complete_and_complete (void)
 static void
 test_message_printable_common (const guint8 *buffer,
                                guint         buffer_len,
+                               guint16       vendor_id,
                                const gchar  *expected_in_printable)
 {
-    QmiMessage *message;
-    GByteArray *array;
-    GError *error = NULL;
-    gchar *printable;
+    g_autoptr(QmiMessageContext)  context = NULL;
+    g_autoptr(QmiMessage)         message = NULL;
+    g_autoptr(GByteArray)         array = NULL;
+    g_autoptr(GError)             error = NULL;
+    g_autofree gchar             *printable = NULL;
+
+    if (vendor_id != QMI_MESSAGE_VENDOR_GENERIC) {
+        context = qmi_message_context_new ();
+        qmi_message_context_set_vendor_id (context, vendor_id);
+    }
 
     array = g_byte_array_sized_new (buffer_len);
     g_byte_array_append (array, buffer, buffer_len);
@@ -190,15 +183,9 @@ test_message_printable_common (const guint8 *buffer,
     g_assert_no_error (error);
     g_assert (message);
 
-    printable = qmi_message_get_printable_full (message, NULL, "");
-#ifdef TEST_PRINT_MESSAGE
-    g_print ("\n%s\n", printable);
-#endif
+    printable = qmi_message_get_printable_full (message, context, "");
+    g_debug ("%s", printable);
     g_assert (strstr (printable, expected_in_printable));
-    g_free (printable);
-
-    g_byte_array_unref (array);
-    qmi_message_unref (message);
 }
 
 static void
@@ -214,9 +201,11 @@ test_message_parse_wrong_tlv (void)
         0x06, 0x00, 0x01, 0x01, 0x01, 0x02, 0x01, 0x05
     };
 
-    test_message_printable_common (buffer, G_N_ELEMENTS (buffer), "ERROR: Reading TLV would overflow");
+    test_message_printable_common (buffer, G_N_ELEMENTS (buffer), QMI_MESSAGE_VENDOR_GENERIC, "ERROR: Reading TLV would overflow");
 }
 
+#if defined HAVE_QMI_INDICATION_PDS_EVENT_REPORT
+
 static void
 test_message_parse_missing_size (void)
 {
@@ -237,9 +226,13 @@ test_message_parse_missing_size (void)
         0x01
     };
 
-    test_message_printable_common (buffer, G_N_ELEMENTS (buffer), "ERROR: Reading TLV would overflow");
+    test_message_printable_common (buffer, G_N_ELEMENTS (buffer), QMI_MESSAGE_VENDOR_GENERIC, "ERROR: Reading TLV would overflow");
 }
 
+#endif
+
+#if defined HAVE_QMI_INDICATION_LOC_NMEA
+
 static void
 test_message_parse_string_with_crlf (void)
 {
@@ -254,9 +247,38 @@ test_message_parse_string_with_crlf (void)
         0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2A, 0x31, 0x45, 0x0D, 0x0A
     };
 
-    test_message_printable_common (buffer, sizeof (buffer), "$GPGSA,A,1,,,,,,,,,,,,,,,*1E");
+    test_message_printable_common (buffer, sizeof (buffer), QMI_MESSAGE_VENDOR_GENERIC, "$GPGSA,A,1,,,,,,,,,,,,,,,*1E");
 }
 
+#endif
+
+#if defined HAVE_QMI_MESSAGE_DMS_SWI_GET_CURRENT_FIRMWARE
+
+static void
+test_message_parse_string_with_trailing_nul (void)
+{
+    /* The Sierra Wireless (vid 0x1199) specific method to get current firmware
+     * info uses NUL-terminated strings.
+     */
+    const guint8 buffer[] = {
+        0x01, 0x82, 0x00, 0x80, 0x02, 0x03, 0x02, 0x01, 0x00, 0x56, 0x55, 0x76,
+        0x00, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x0C, 0x00, 0x30,
+        0x30, 0x32, 0x2E, 0x30, 0x37, 0x32, 0x5F, 0x30, 0x30, 0x30, 0x00, 0x17,
+        0x08, 0x00, 0x47, 0x45, 0x4E, 0x45, 0x52, 0x49, 0x43, 0x00, 0x16, 0x08,
+        0x00, 0x30, 0x30, 0x30, 0x2E, 0x30, 0x30, 0x35, 0x00, 0x15, 0x02, 0x00,
+        0x31, 0x00, 0x13, 0x08, 0x00, 0x31, 0x31, 0x30, 0x32, 0x34, 0x37, 0x36,
+        0x00, 0x12, 0x15, 0x00, 0x53, 0x57, 0x49, 0x39, 0x58, 0x33, 0x30, 0x43,
+        0x5F, 0x30, 0x32, 0x2E, 0x33, 0x33, 0x2E, 0x30, 0x33, 0x2E, 0x30, 0x30,
+        0x00, 0x11, 0x15, 0x00, 0x53, 0x57, 0x49, 0x39, 0x58, 0x33, 0x30, 0x43,
+        0x5F, 0x30, 0x32, 0x2E, 0x33, 0x33, 0x2E, 0x30, 0x33, 0x2E, 0x30, 0x30,
+        0x00, 0x10, 0x07, 0x00, 0x4D, 0x43, 0x37, 0x34, 0x35, 0x35, 0x00
+    };
+
+    test_message_printable_common (buffer, sizeof (buffer), 0x1199, "SWI9X30C_02.33.03.00");
+}
+
+#endif
+
 /*****************************************************************************/
 
 static void
@@ -274,10 +296,10 @@ test_message_new_request (void)
         0x00, 0x00, /* all tlvs length */
     };
 
-    QmiMessage *self;
-    GError *error = NULL;
-    const guint8 *buffer;
-    gsize buffer_length = 0;
+    g_autoptr(QmiMessage)  self = NULL;
+    g_autoptr(GError)      error = NULL;
+    const guint8          *buffer;
+    gsize                  buffer_length = 0;
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
     g_assert (self);
@@ -288,8 +310,6 @@ test_message_new_request (void)
     g_assert_cmpuint (buffer_length, >, 0);
 
     _g_assert_cmpmem (buffer, buffer_length, expected_buffer, sizeof (expected_buffer));
-
-    qmi_message_unref (self);
 }
 
 static void
@@ -302,11 +322,11 @@ test_message_new_request_from_data (void)
         0x00, 0x00, /* all tlvs length */
     };
 
-    GByteArray *qmi;
-    QmiMessage *self;
-    GError *error = NULL;
-    const guint8 *buffer;
-    gsize buffer_length = 0;
+    g_autoptr(GByteArray)  qmi = NULL;
+    g_autoptr(QmiMessage)  self = NULL;
+    g_autoptr(GError)      error = NULL;
+    const guint8          *buffer;
+    gsize                  buffer_length = 0;
 
     /* set up service header */
     qmi = g_byte_array_new ();
@@ -340,9 +360,6 @@ test_message_new_request_from_data (void)
     g_assert (buffer != NULL);
     g_assert_cmpuint (buffer_length, >, 0);
     _g_assert_cmpmem (buffer, buffer_length, expected_buffer, sizeof (expected_buffer));
-
-    qmi_message_unref (self);
-    g_byte_array_unref (qmi);
 }
 
 static void
@@ -364,11 +381,11 @@ test_message_new_response_ok (void)
         0x00, 0x00, 0x00, 0x00
     };
 
-    QmiMessage *request;
-    QmiMessage *response;
-    GError *error = NULL;
-    const guint8 *buffer;
-    gsize buffer_length = 0;
+    g_autoptr(QmiMessage)  request = NULL;
+    g_autoptr(QmiMessage)  response = NULL;
+    g_autoptr(GError)      error = NULL;
+    const guint8          *buffer;
+    gsize                  buffer_length = 0;
 
     request = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
     g_assert (request);
@@ -382,9 +399,6 @@ test_message_new_response_ok (void)
     g_assert_cmpuint (buffer_length, >, 0);
 
     _g_assert_cmpmem (buffer, buffer_length, expected_buffer, sizeof (expected_buffer));
-
-    qmi_message_unref (request);
-    qmi_message_unref (response);
 }
 
 static void
@@ -406,11 +420,11 @@ test_message_new_response_error (void)
         0x01, 0x00, 0x03, 0x00
     };
 
-    QmiMessage *request;
-    QmiMessage *response;
-    GError *error = NULL;
-    const guint8 *buffer;
-    gsize buffer_length = 0;
+    g_autoptr(QmiMessage)  request = NULL;
+    g_autoptr(QmiMessage)  response = NULL;
+    g_autoptr(GError)      error = NULL;
+    const guint8          *buffer;
+    gsize                  buffer_length = 0;
 
     request = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
     g_assert (request);
@@ -424,9 +438,6 @@ test_message_new_response_error (void)
     g_assert_cmpuint (buffer_length, >, 0);
 
     _g_assert_cmpmem (buffer, buffer_length, expected_buffer, sizeof (expected_buffer));
-
-    qmi_message_unref (request);
-    qmi_message_unref (response);
 }
 
 /*****************************************************************************/
@@ -434,10 +445,10 @@ test_message_new_response_error (void)
 static void
 test_message_tlv_write_empty (void)
 {
-    QmiMessage *self;
-    GError *error = NULL;
-    gboolean ret;
-    gsize init_offset;
+    g_autoptr(QmiMessage) self = NULL;
+    g_autoptr(GError)     error = NULL;
+    gboolean              ret;
+    gsize                 init_offset;
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
 
@@ -448,18 +459,16 @@ test_message_tlv_write_empty (void)
     ret = qmi_message_tlv_write_complete (self, init_offset, &error);
     g_assert_no_error (error);
     g_assert (ret);
-
-    qmi_message_unref (self);
 }
 
 static void
 test_message_tlv_write_reset (void)
 {
-    QmiMessage *self;
-    GError *error = NULL;
-    gboolean ret;
-    gsize init_offset;
-    gsize previous_size;
+    g_autoptr(QmiMessage) self = NULL;
+    g_autoptr(GError)     error = NULL;
+    gboolean              ret;
+    gsize                 init_offset;
+    gsize                 previous_size;
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
     previous_size = qmi_message_get_length (self);
@@ -483,22 +492,20 @@ test_message_tlv_write_reset (void)
 
     qmi_message_tlv_write_reset (self, init_offset);
     g_assert_cmpuint (previous_size, ==, qmi_message_get_length (self));
-
-    qmi_message_unref (self);
 }
 
 static void
 test_message_tlv_rw_8 (void)
 {
-    QmiMessage *self;
-    GError *error = NULL;
-    gboolean ret;
-    gsize init_offset;
-    gsize expected_tlv_payload_size = 0;
-    guint16 tlv_length = 0;
-    gsize offset;
-    guint8 uint8;
-    gint8 int8;
+    g_autoptr(QmiMessage) self = NULL;
+    g_autoptr(GError)     error = NULL;
+    gboolean              ret;
+    gsize                 init_offset;
+    gsize                 expected_tlv_payload_size = 0;
+    guint16               tlv_length = 0;
+    gsize                 offset;
+    guint8                uint8;
+    gint8                 int8;
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
 
@@ -538,8 +545,6 @@ test_message_tlv_rw_8 (void)
     g_assert_no_error (error);
     g_assert (ret);
     g_assert_cmpuint (int8, ==, 0 - 0x12);
-
-    qmi_message_unref (self);
 }
 
 static void
@@ -550,16 +555,16 @@ test_message_tlv_rw_16 (void)
     /* We'll add [0 or 1] bytes before the actual 16-bit values, so that we
      * check all possible memory alignments. */
     for (n_bytes_prefixed = 0; n_bytes_prefixed <= 1; n_bytes_prefixed++) {
-        QmiMessage *self;
-        GError *error = NULL;
-        gboolean ret;
-        gsize init_offset;
-        guint16 tlv_length = 0;
-        gsize offset;
-        gsize expected_tlv_payload_size = 0;
-        guint16 uint16;
-        gint16 int16;
-        guint i;
+        g_autoptr(QmiMessage) self = NULL;
+        g_autoptr(GError)     error = NULL;
+        gboolean              ret;
+        gsize                 init_offset;
+        guint16               tlv_length = 0;
+        gsize                 offset;
+        gsize                 expected_tlv_payload_size = 0;
+        guint16               uint16;
+        gint16                int16;
+        guint                 i;
 
         self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
 
@@ -635,8 +640,6 @@ test_message_tlv_rw_16 (void)
         g_assert_no_error (error);
         g_assert (ret);
         g_assert_cmpuint (int16, ==, 0 - 0x1212);
-
-        qmi_message_unref (self);
     }
 }
 
@@ -648,16 +651,16 @@ test_message_tlv_rw_32 (void)
     /* We'll add [0, 1, 2, 3] bytes before the actual 32-bit values, so that we
      * check all possible memory alignments. */
     for (n_bytes_prefixed = 0; n_bytes_prefixed <= 3; n_bytes_prefixed++) {
-        QmiMessage *self;
-        GError *error = NULL;
-        gboolean ret;
-        gsize init_offset;
-        guint16 tlv_length = 0;
-        gsize offset;
-        gsize expected_tlv_payload_size = 0;
-        guint32 uint32;
-        gint32 int32;
-        guint i;
+        g_autoptr(QmiMessage) self = NULL;
+        g_autoptr(GError)     error = NULL;
+        gboolean              ret;
+        gsize                 init_offset;
+        guint16               tlv_length = 0;
+        gsize                 offset;
+        gsize                 expected_tlv_payload_size = 0;
+        guint32               uint32;
+        gint32                int32;
+        guint                 i;
 
         self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
 
@@ -733,8 +736,6 @@ test_message_tlv_rw_32 (void)
         g_assert_no_error (error);
         g_assert (ret);
         g_assert_cmpuint (int32, ==, 0 - 0x12121212);
-
-        qmi_message_unref (self);
     }
 }
 
@@ -746,16 +747,16 @@ test_message_tlv_rw_64 (void)
     /* We'll add [0, 1, 2, 3, 4, 5, 6, 7] bytes before the actual 64-bit values,
      * so that we check all possible memory alignments. */
     for (n_bytes_prefixed = 0; n_bytes_prefixed <= 7; n_bytes_prefixed++) {
-        QmiMessage *self;
-        GError *error = NULL;
-        gboolean ret;
-        gsize init_offset;
-        guint16 tlv_length = 0;
-        gsize offset;
-        gsize expected_tlv_payload_size = 0;
-        guint64 uint64;
-        gint64 int64;
-        guint i;
+        g_autoptr(QmiMessage) self = NULL;
+        g_autoptr(GError)     error = NULL;
+        gboolean              ret;
+        gsize                 init_offset;
+        guint16               tlv_length = 0;
+        gsize                 offset;
+        gsize                 expected_tlv_payload_size = 0;
+        guint64               uint64;
+        gint64                int64;
+        guint                 i;
 
         self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
 
@@ -831,8 +832,6 @@ test_message_tlv_rw_64 (void)
         g_assert_no_error (error);
         g_assert (ret);
         g_assert_cmpuint (int64, ==, 0 - 0x1212121212121212LL);
-
-        qmi_message_unref (self);
     }
 }
 
@@ -848,17 +847,17 @@ test_message_tlv_rw_sized (void)
         /* We'll add [0, 1, 2, 3, 4, 5, 6, 7] bytes before the actual N-bit values,
          * so that we check all possible memory alignments. */
         for (n_bytes_prefixed = 0; n_bytes_prefixed <= sized[sized_i] - 1; n_bytes_prefixed++) {
-            QmiMessage *self;
-            GError *error = NULL;
-            gboolean ret;
-            gsize init_offset;
-            guint16 tlv_length = 0;
-            gsize offset;
-            gsize expected_tlv_payload_size = 0;
-            guint64 uint64;
-            guint i;
-            guint64 value;
-            guint64 tmp;
+            g_autoptr(QmiMessage) self = NULL;
+            g_autoptr(GError)     error = NULL;
+            gboolean              ret;
+            gsize                 init_offset;
+            guint16               tlv_length = 0;
+            gsize                 offset;
+            gsize                 expected_tlv_payload_size = 0;
+            guint64               uint64;
+            guint                 i;
+            guint64               value;
+            guint64               tmp;
 
             value = 0x1212121212121212ULL;
             tmp = 0xFF;
@@ -918,8 +917,6 @@ test_message_tlv_rw_sized (void)
 
             qmi_message_tlv_read_sized_guint (self, init_offset, &offset, sized[sized_i], QMI_ENDIAN_BIG, &uint64, &error);
             g_assert_cmpuint (uint64, ==, value);
-
-            qmi_message_unref (self);
         }
     }
 }
@@ -927,15 +924,15 @@ test_message_tlv_rw_sized (void)
 static void
 test_message_tlv_rw_strings (void)
 {
-    QmiMessage *self;
-    GError *error = NULL;
-    gboolean ret;
-    gsize init_offset;
-    guint16 tlv_length = 0;
-    gsize offset;
-    gsize expected_tlv_payload_size = 0;
-    gchar *str;
-    gchar fixed_str[5];
+    g_autoptr(QmiMessage)  self = NULL;
+    g_autoptr(GError)      error = NULL;
+    gboolean               ret;
+    gsize                  init_offset;
+    guint16                tlv_length = 0;
+    gsize                  offset;
+    gsize                  expected_tlv_payload_size = 0;
+    gchar                 *str;
+    gchar                  fixed_str[5];
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
 
@@ -1046,28 +1043,26 @@ test_message_tlv_rw_strings (void)
     g_assert (ret);
     g_assert_cmpstr (str, ==, "");
     g_free (str);
-
-    qmi_message_unref (self);
 }
 
 static void
 test_message_tlv_rw_mixed (void)
 {
-    QmiMessage *self;
-    GError *error = NULL;
-    gboolean ret;
-    gsize init_offset;
-    guint16 tlv_length = 0;
-    gsize offset;
-    gsize expected_tlv_payload_size = 0;
-    guint8 uint8;
-    gint8  int8;
-    guint16 uint16;
-    gint16 int16;
-    guint32 uint32;
-    gint32 int32;
-    guint64 uint64;
-    gint64 int64;
+    g_autoptr(QmiMessage) self = NULL;
+    g_autoptr(GError)     error = NULL;
+    gboolean              ret;
+    gsize                 init_offset;
+    guint16               tlv_length = 0;
+    gsize                 offset;
+    gsize                 expected_tlv_payload_size = 0;
+    guint8                uint8;
+    gint8                 int8;
+    guint16               uint16;
+    gint16                int16;
+    guint32               uint32;
+    gint32                int32;
+    guint64               uint64;
+    gint64                int64;
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
 
@@ -1182,17 +1177,15 @@ test_message_tlv_rw_mixed (void)
     g_assert_no_error (error);
     g_assert (ret);
     g_assert_cmpuint (int64, ==, 0 - 0x1212121212121212LL);
-
-    qmi_message_unref (self);
 }
 
 static void
 test_message_tlv_write_overflow (void)
 {
-    QmiMessage *self;
-    GError *error = NULL;
-    gsize init_offset;
-    gboolean ret;
+    g_autoptr(QmiMessage) self = NULL;
+    g_autoptr(GError)     error = NULL;
+    gboolean              ret;
+    gsize                 init_offset;
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
 
@@ -1283,28 +1276,26 @@ test_message_tlv_write_overflow (void)
     g_assert_error (error, QMI_CORE_ERROR, QMI_CORE_ERROR_TLV_TOO_LONG);
     g_assert (init_offset == 0);
     g_clear_error (&error);
-
-    qmi_message_unref (self);
 }
 
 static void
 test_message_tlv_read_overflow_message (void)
 {
-    QmiMessage *self;
-    GError *error = NULL;
-    gsize init_offset;
-    guint16 tlv_length = 0;
-    gsize offset;
-    gboolean ret;
-    gchar *str;
-    guint8 uint8;
-    gint8  int8;
-    guint16 uint16;
-    gint16 int16;
-    guint32 uint32;
-    gint32 int32;
-    guint64 uint64;
-    gint64 int64;
+    g_autoptr(QmiMessage)  self = NULL;
+    g_autoptr(GError)      error = NULL;
+    gboolean               ret;
+    gsize                  init_offset;
+    guint16                tlv_length = 0;
+    gsize                  offset;
+    gchar                 *str;
+    guint8                 uint8;
+    gint8                  int8;
+    guint16                uint16;
+    gint16                 int16;
+    guint32                uint32;
+    gint32                 int32;
+    guint64                uint64;
+    gint64                 int64;
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
     init_offset = qmi_message_tlv_write_init (self, 0x01, &error);
@@ -1329,7 +1320,7 @@ test_message_tlv_read_overflow_message (void)
     g_assert_error (error, QMI_CORE_ERROR, QMI_CORE_ERROR_TLV_TOO_LONG);
     g_assert (!ret);
     g_clear_error (&error);
-    qmi_message_unref (self);
+    g_clear_pointer (&self, qmi_message_unref);
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
     init_offset = qmi_message_tlv_write_init (self, 0x01, &error);
@@ -1392,27 +1383,27 @@ test_message_tlv_read_overflow_message (void)
     g_assert_error (error, QMI_CORE_ERROR, QMI_CORE_ERROR_TLV_TOO_LONG);
     g_assert (!ret);
     g_clear_error (&error);
-    qmi_message_unref (self);
+    g_clear_pointer (&self, qmi_message_unref);
 }
 
 static void
 test_message_tlv_read_overflow_tlv (void)
 {
-    QmiMessage *self;
-    GError *error = NULL;
-    gsize init_offset;
-    guint16 tlv_length = 0;
-    gsize offset;
-    gboolean ret;
-    gchar *str;
-    guint8 uint8;
-    gint8  int8;
-    guint16 uint16;
-    gint16 int16;
-    guint32 uint32;
-    gint32 int32;
-    guint64 uint64;
-    gint64 int64;
+    g_autoptr(QmiMessage)  self = NULL;
+    g_autoptr(GError)      error = NULL;
+    gboolean               ret;
+    gsize                  init_offset;
+    guint16                tlv_length = 0;
+    gsize                  offset;
+    gchar                 *str;
+    guint8                 uint8;
+    gint8                  int8;
+    guint16                uint16;
+    gint16                 int16;
+    guint32                uint32;
+    gint32                 int32;
+    guint64                uint64;
+    gint64                 int64;
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
     init_offset = qmi_message_tlv_write_init (self, 0x01, &error);
@@ -1446,8 +1437,7 @@ test_message_tlv_read_overflow_tlv (void)
     g_assert_error (error, QMI_CORE_ERROR, QMI_CORE_ERROR_TLV_TOO_LONG);
     g_assert (!ret);
     g_clear_error (&error);
-    qmi_message_unref (self);
-
+    g_clear_pointer (&self, qmi_message_unref);
 
     self = qmi_message_new (QMI_SERVICE_DMS, 0x01, 0x02, 0xFFFF);
     init_offset = qmi_message_tlv_write_init (self, 0x01, &error);
@@ -1519,7 +1509,7 @@ test_message_tlv_read_overflow_tlv (void)
     g_assert_error (error, QMI_CORE_ERROR, QMI_CORE_ERROR_TLV_TOO_LONG);
     g_assert (!ret);
     g_clear_error (&error);
-    qmi_message_unref (self);
+    g_clear_pointer (&self, qmi_message_unref);
 }
 
 /*****************************************************************************/
@@ -1527,10 +1517,11 @@ test_message_tlv_read_overflow_tlv (void)
 static void
 test_message_set_transaction_id_ctl (void)
 {
-    GByteArray *buffer;
-    QmiMessage *message;
-    GError     *error = NULL;
-    guint8      ctl_message[] = {
+    g_autoptr(GByteArray) buffer = NULL;
+    g_autoptr(QmiMessage) message = NULL;
+    g_autoptr(GError)     error = NULL;
+
+    guint8 ctl_message[] = {
         0x01, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00,
         0xFF, /* TRID to update */
         0x22, 0x00, 0x04, 0x00, 0x01, 0x01, 0x00, 0x01
@@ -1544,18 +1535,16 @@ test_message_set_transaction_id_ctl (void)
 
     qmi_message_set_transaction_id (message, 0x55);
     g_assert_cmpuint (qmi_message_get_transaction_id (message), ==, 0x55);
-
-    qmi_message_unref (message);
-    g_byte_array_unref (buffer);
 }
 
 static void
 test_message_set_transaction_id_services (void)
 {
-    GByteArray *buffer;
-    QmiMessage *message;
-    GError     *error = NULL;
-    guint8      dms_message[] = {
+    g_autoptr(GByteArray) buffer = NULL;
+    g_autoptr(QmiMessage) message = NULL;
+    g_autoptr(GError)     error = NULL;
+
+    guint8 dms_message[] = {
         0x01, 0x0C, 0x00, 0x00, 0x02, 0x01, 0x00,
         0xFF, 0xFF, /* TRID to update */
         0x25, 0x00, 0x00, 0x00
@@ -1569,9 +1558,6 @@ test_message_set_transaction_id_services (void)
 
     qmi_message_set_transaction_id (message, 0x5566);
     g_assert_cmpuint (qmi_message_get_transaction_id (message), ==, 0x5566);
-
-    qmi_message_unref (message);
-    g_byte_array_unref (buffer);
 }
 
 /*****************************************************************************/
@@ -1585,8 +1571,15 @@ int main (int argc, char **argv)
     g_test_add_func ("/libqmi-glib/message/parse/complete-and-short",    test_message_parse_complete_and_short);
     g_test_add_func ("/libqmi-glib/message/parse/complete-and-complete", test_message_parse_complete_and_complete);
     g_test_add_func ("/libqmi-glib/message/parse/wrong-tlv",             test_message_parse_wrong_tlv);
+#if defined HAVE_QMI_INDICATION_PDS_EVENT_REPORT
     g_test_add_func ("/libqmi-glib/message/parse/missing-size",          test_message_parse_missing_size);
+#endif
+#if defined HAVE_QMI_INDICATION_LOC_NMEA
     g_test_add_func ("/libqmi-glib/message/parse/string-with-crlf",      test_message_parse_string_with_crlf);
+#endif
+#if defined HAVE_QMI_MESSAGE_DMS_SWI_GET_CURRENT_FIRMWARE
+    g_test_add_func ("/libqmi-glib/message/parse/string-with-trailing-nul", test_message_parse_string_with_trailing_nul);
+#endif
 
     g_test_add_func ("/libqmi-glib/message/new/request",           test_message_new_request);
     g_test_add_func ("/libqmi-glib/message/new/request-from-data", test_message_new_request_from_data);
